--------
Notifier
--------

.. currentmodule:: oslo_messaging

.. autoclass:: Notifier
   :members:

.. autoclass:: LoggingNotificationHandler
   :members:

.. autoclass:: LoggingErrorNotificationHandler
   :members:
